@@ -15,6 +15,7 @@ class DatabaseOperations(PostgresDatabaseOperations):
         'IntegerField': (-9223372036854775808, 9223372036854775807),
         'BigIntegerField': (-9223372036854775808, 9223372036854775807),
         'PositiveSmallIntegerField': (0, 32767),
+        'PositiveBigIntegerField': (0, 9223372036854775807),
         'PositiveIntegerField': (0, 9223372036854775807),
         'SmallAutoField': (-32768, 32767),
         'AutoField': (-9223372036854775808, 9223372036854775807),
@@ -51,22 +52,6 @@ class DatabaseOperations(PostgresDatabaseOperations):
     def sequence_reset_sql(self, style, model_list):
         return []
 
-    def date_extract_sql(self, lookup_type, field_name):
-        # String values in EXTRACT arguments are supported in CockroachDB 20.1.
-        # This method is obsolete when support for CockroachDB < 20.1 is
-        # dropped. https://github.com/cockroachdb/cockroach/pull/41429
-        if self.connection.features.is_cockroachdb_20_1:
-            return super().date_extract_sql(lookup_type, field_name)
-        # Extract SQL is slightly different from PostgreSQL.
-        # https://www.cockroachlabs.com/docs/stable/functions-and-operators.html
-        if lookup_type == 'week_day':
-            # For consistency across backends, return Sunday=1, Saturday=7.
-            return 'EXTRACT(dow FROM %s) + 1' % field_name
-        elif lookup_type == 'iso_year':
-            return 'EXTRACT(isoyear FROM %s)' % field_name
-        else:
-            return 'EXTRACT(%s FROM %s)' % (lookup_type, field_name)
-
     def explain_query_prefix(self, format=None, **options):
         if format:
             raise ValueError("CockroachDB's EXPLAIN doesn't support any formats.")
@@ -76,7 +61,7 @@ class DatabaseOperations(PostgresDatabaseOperations):
             prefix += ' (%s)' % ', '.join(extra)
         return prefix
 
-    def execute_sql_flush(self, using, sql_list):
+    def execute_sql_flush(self, sql_list):
         # Retry TRUNCATE if it fails with a serialization error.
         num_retries = 10
         initial_retry_delay = 0.5  # The initial retry delay, in seconds.
@@ -84,10 +69,14 @@ class DatabaseOperations(PostgresDatabaseOperations):
         next_retry_delay = initial_retry_delay
         for retry in range(1, num_retries + 1):
             try:
-                return super().execute_sql_flush(using, sql_list)
+                return super().execute_sql_flush(sql_list)
             except OperationalError as exc:
                 if (getattr(exc.__cause__, 'pgcode', '') != errorcodes.SERIALIZATION_FAILURE or
                         retry >= num_retries):
                     raise
                 time.sleep(next_retry_delay)
                 next_retry_delay *= backoff_
+
+    def sql_flush(self, style, tables, *, reset_sequences=False, allow_cascade=False):
+        # CockroachDB doesn't support resetting sequences.
+        return super().sql_flush(style, tables, reset_sequences=False, allow_cascade=allow_cascade)
